@@ -29,10 +29,7 @@ impl Frame {
             ],
             Error::MalformedAttributes("A frame must have tileid and duration".to_string())
         );
-        Ok(Frame {
-            tile_id: tile_id,
-            duration: duration,
-        })
+        Ok(Frame { tile_id, duration })
     }
 }
 
