@@ -10,8 +10,10 @@ mod cache;
 mod error;
 mod image;
 mod layers;
+mod loader;
 mod map;
 mod objects;
+mod parse;
 mod properties;
 mod tile;
 mod tileset;
@@ -22,6 +24,7 @@ pub use cache::*;
 pub use error::*;
 pub use image::*;
 pub use layers::*;
+pub use loader::*;
 pub use map::*;
 pub use objects::*;
 pub use properties::*;
